@@ -47,8 +47,9 @@ def getArgumentParser():
     parser.add_argument('--ignore-errors', action='store_true',
                         help='!DANGEROUS! ignore errors in the sub threads. This may cause incomplete dumps.')
     parser.add_argument('--ignore-action-disabled-edit', action='store_true',
-                        help='Some sites disable edit action for anonymous users and some core pages.'+
-                        'This option will ignore this error. But you may only get a partial dump. '+
+                        help='Some sites disable edit action for anonymous users and some core pages. '+
+                        'This option will ignore this error and textarea not found error.'+
+                        'But you may only get a partial dump. '+
                         '(only works with --content)', dest='ignore_action_disabled_edit')
 
     parser.add_argument('--username', help='login: username')
@@ -160,16 +161,16 @@ def dump():
                     session=session, skipTo=skip_to, threads=args.threads,
                     ignore_errors=args.ignore_errors,
                     ignore_action_disabled_edit=args.ignore_action_disabled_edit)
-    if args.media:
-        print('\nDumping media...\n')
-        dumpMedia(url=base_url, dumpDir=dumpDir,
-                  session=session, threads=args.threads,
-                  ignore_errors=args.ignore_errors)
     if args.html:
         print('\nDumping HTML...\n')
         dump_HTML(doku_url=doku_url, dumpDir=dumpDir,
                   session=session, skipTo=skip_to, threads=args.threads,
                   ignore_errors=args.ignore_errors)
+    if args.media: # last, so that we can know the dump is complete.
+        print('\nDumping media...\n')
+        dumpMedia(url=base_url, dumpDir=dumpDir,
+                  session=session, threads=args.threads,
+                  ignore_errors=args.ignore_errors)
 
 
     print('\n\n--Done--')
